import json
import sys

from testwizard.commands_core.ResultBase import ResultBase

class ScreenshotResult(ResultBase):
    def __init__(self, result, successMessage, failMessage):
        ResultBase.__init__(self, result["ok"] is True, successMessage, failMessage)

        self.filePath = result["generatedFilename"]

        if self.success is True:
            return

        self.message = self.message + result["errorMessage"]