from .AddCapabilityCommand import AddCapabilityCommand
from .Android_SendKeyCodeCommand import Android_SendKeyCodeCommand
from .ClearElementCommand import ClearElementCommand
from .ClickElementCommand import ClickElementCommand
from .ClickPositionCommand import ClickPositionCommand
from .CloseAppCommand import CloseAppCommand
from .RemoveAppCommand import RemoveAppCommand
from .FindElementCommand import FindElementCommand
from .GetAppiumSettingsCommand import GetAppiumSettingsCommand
from .GetElementCommand import GetElementCommand
from .GetElementAttributeCommand import GetElementAttributeCommand
from .GetElementLocationCommand import GetElementLocationCommand
from .GetElementsCommand import GetElementsCommand
from .GetElementSizeCommand import GetElementSizeCommand
from .GetOrientationCommand import GetOrientationCommand
from .GetScreenSizeCommand import GetScreenSizeCommand
from .GetSourceCommand import GetSourceCommand
from .HideKeyboardCommand import HideKeyboardCommand
from .InitDriverCommand import InitDriverCommand
from .InputTextCommand import InputTextCommand
from .LaunchAppCommand import LaunchAppCommand
from .MultiTouch_AddCommand import MultiTouch_AddCommand
from .MultiTouch_NewCommand import MultiTouch_NewCommand
from .MultiTouch_PerformCommand import MultiTouch_PerformCommand
from .PinchCoordinatesCommand import PinchCoordinatesCommand
from .PinchElementCommand import PinchElementCommand
from .QuitDriverCommand import QuitDriverCommand
from .ResetAppCommand import ResetAppCommand
from .RunAppInBackgroundCommand import RunAppInBackgroundCommand
from .ScreenshotBMPCommand import ScreenshotBMPCommand
from .ScreenShotJPGCommand import ScreenShotJPGCommand
from .SetAppiumSettingsCommand import SetAppiumSettingsCommand
from .SetOrientationCommand import SetOrientationCommand
from .StartDeviceLoggingCommand import StartDeviceLoggingCommand
from .StopDeviceLoggingCommand import StopDeviceLoggingCommand
from .SwipeArcCommand import SwipeArcCommand
from .SwipeCommand import SwipeCommand
from .TouchAction_MoveToCommand import TouchAction_MoveToCommand
from .TouchAction_MoveToElementCommand import TouchAction_MoveToElementCommand
from .TouchAction_NewCommand import TouchAction_NewCommand
from .TouchAction_PerformCommand import TouchAction_PerformCommand
from .TouchAction_PressCommand import TouchAction_PressCommand
from .TouchAction_PressElementCommand import TouchAction_PressElementCommand
from .TouchAction_ReleaseCommand import TouchAction_ReleaseCommand
from .TouchAction_TapCommand import TouchAction_TapCommand
from .TouchAction_WaitCommand import TouchAction_WaitCommand
from .WaitForElementCommand import WaitForElementCommand
from .ZoomCoordinatesCommand import ZoomCoordinatesCommand
from .ZoomElementCommand import ZoomElementCommand
